==> 0.1.1.tar.gz: lib/empirical.dart <==
library empirical;

import 'dart:html';

part 'package:empirical/src/canvas_interface.dart';
part 'package:empirical/src/menu_interface.dart';

abstract class Empirical {
  var paused = false, started = false;

  Empirical() {
    canvasInterface(); ///Loads necessary styles etc.
    loadInterface();
    loadEvents();
    window.requestAnimationFrame(_tick);
  }
  
  /**
   * A function that enables the super class to override so the default 
   * Interface Menus can be edited allowing for much more customized games.
   * super.Interface() should almost definitely be called, if overwritten.
   */
  loadInterface() {
    createAllMenus();
    _resize();
    showMenu(getMenu(MAIN));
  }

  /**
   * Controls the logic that occurs when an exit button is pressed on
   * certain types of menus.
   * Including: MainMenu, PauseMenu and OptionsMenu by default.
   */
  exitMenu() {
    switch (currentMenu.runtimeType) {
      case MainMenu:
        window.history.back();
        return;
      case PauseMenu:
        _end();
        showMenu(getMenu(MAIN));
        return;
      case OptionsMenu:
      default:
        showMenu(getMenu(MAIN));
        return;
    }
  }

  loadEvents() {
    assert(query('#startbutton') != null); 
    assert(query('#pausebutton') != null); 
    assert(query('#optionsbutton') != null); 
    assert(queryAll('#exitbutton') != null);
    
    query('#startbutton').onClick.listen((event) {
      showMenu(getMenu(GAME));
      _start();
    });
    query('#pausebutton').onClick.listen((event) {
      _pause();
    });
    query('#optionsbutton').onClick.listen((event) {
      showMenu(OPTIONS);
    });
    queryAll('#exitbutton').forEach((element) {
      element.onClick.listen((event) {
        exitMenu();
      });
    });
    window.onKeyDown.listen((event) {
      switch(event.keyCode) {
        case 80:
          if (started) _pause();
          return;
        case 82:
          if (!paused && started) restartGame();
          return;
        default:
          if (!paused && started)  keyDownGame(event.keyCode);
          return;
      }
    });
    canvas.onClick.listen((MouseEvent event) {
      if (!paused && started) {
        var coords = relMouseCoords(event);
        clickGame(coords.x, coords.y);
      }
    });
    window.onResize.listen((event) {
      _resize();
    });
  }
  
  Point relMouseCoords(event){
    var totalOffsetX = canvas.offsetLeft - canvas.scrollLeft;
    var totalOffsetY = canvas.offsetTop - canvas.scrollTop;
    var canvasX = event.pageX - totalOffsetX;
    var canvasY = event.pageY - totalOffsetY;
    return new Point(canvasX, canvasY);
}

  _tick(num time) {
    if (!paused && started) {
      _draw();
      tickGame();
    }
    window.requestAnimationFrame(_tick);
  }
  
  _draw() {
    context.fillStyle = 'black';
    context.fillRect(0, 0, canvas.width, canvas.height);
    drawGame();
  }
  
  _start() {
    paused = false;
    started = true;
    startGame();
  }
  
  _end() {
    started = false;
    //_pause(); ///Ensures that if the game is started again it won't be paused.
    endGame();
  }
  
  _pause() {
    paused = !paused;
    if (paused && started) {
      showMenu(getMenu(PAUSE));
    } else {
      showMenu(getMenu(GAME));
    }
    pauseGame();
  }
  
  _resize() {
    resizeCanvas();
    resizeGame();
    _draw(); ///Experiment, requires there to be no logic on draw function.
  }
  
  drawGame(); 
  startGame();
  endGame();
  pauseGame();
  restartGame();
  resizeGame();
  tickGame();
  keyDownGame(keyCode);
  clickGame(x, y);
}

==> 0.1.2.tar.gz: lib/empirical.dart <==
library empirical;

import 'dart:html';

part 'package:empirical/src/style_interface.dart';
part 'package:empirical/src/menu_interface.dart';

abstract class Empirical {
  var paused = false, started = false;

  Empirical() {
    loadStyles(); ///Loads necessary styles etc.
    loadInterface();
    loadEvents();
    window.requestAnimationFrame(_tick);
  }
  
  /**
   * A function that enables the super class to override so the default 
   * Interface Menus can be edited allowing for much more customized games.
   * super.Interface() should almost definitely be called, if overwritten.
   */
  loadInterface() {
    createAllMenus();
    _resize();
    showMenu(getMenu(MAIN));
  }

  /**
   * Controls the logic that occurs when an exit button is pressed on
   * certain types of menus.
   * Including: MainMenu, PauseMenu and OptionsMenu by default.
   */
  exitMenu() {
    switch (currentMenu.runtimeType) {
      case MainMenu:
        window.history.back();
        return;
      case PauseMenu:
        _end();
        showMenu(getMenu(MAIN));
        return;
      case OptionsMenu:
      default:
        showMenu(getMenu(MAIN));
        return;
    }
  }

  loadEvents() {
    assert(query('#startbutton') != null); 
    assert(query('#pausebutton') != null); 
    assert(query('#optionsbutton') != null); 
    assert(queryAll('#exitbutton') != null);
    
    query('#startbutton').onClick.listen((event) {
      showMenu(getMenu(GAME));
      _start();
    });
    query('#pausebutton').onClick.listen((event) {
      _pause();
    });
    query('#optionsbutton').onClick.listen((event) {
      showMenu(OPTIONS);
    });
    queryAll('#exitbutton').forEach((element) {
      element.onClick.listen((event) {
        exitMenu();
      });
    });
    window.onKeyDown.listen((event) {
      if (!started) return;
      switch(event.keyCode) {
        case 80:
          _pause();
          return;
        case 82:
          if (!paused) restartGame();
          return;
        default:
          if (!paused)  keyDownGame(event.keyCode);
          return;
      }
    });
    canvas.onClick.listen((MouseEvent event) {
      if (!paused && started) {
        var coords = relMouseCoords(event);
        clickGame(coords.x, coords.y);
      }
    });
    window.onResize.listen((event) {
      _resize();
    });
  }
  
  Point relMouseCoords(event){
    var totalOffsetX = canvas.offsetLeft - canvas.scrollLeft;
    var totalOffsetY = canvas.offsetTop - canvas.scrollTop;
    var canvasX = event.pageX - totalOffsetX;
    var canvasY = event.pageY - totalOffsetY;
    return new Point(canvasX, canvasY);
}

  _tick(num time) {
    if (!paused && started) {
      _draw();
      tickGame();
    }
    window.requestAnimationFrame(_tick);
  }
  
  _draw() {
    context.fillStyle = 'black';
    context.fillRect(0, 0, canvas.width, canvas.height);
    drawGame();
  }
  
  _start() {
    paused = false;
    started = true;
    startGame();
  }
  
  _end() {
    started = false;
    endGame();
  }
  
  _pause() {
    paused = !paused;
    if (paused && started) {
      showMenu(getMenu(PAUSE));
    } else {
      showMenu(getMenu(GAME));
    }
    pauseGame();
  }
  
  _resize() {
    resizeCanvas();
    resizeGame();
    _draw(); ///Experiment, requires there to be no logic on draw function.
  }
  
  restartGame() {
    endGame();
    startGame();
  }
  
  drawGame(); 
  startGame();
  endGame();
  pauseGame();
  resizeGame();
  tickGame();
  keyDownGame(keyCode);
  clickGame(x, y);
}
